@@ -1,12 +1,14 @@
 #' @rdname dgmcm.loglik
 pgmm.marginal <- function (z, theta) {
-  if (!is.theta(theta))
-    stop("theta is formatted correctly")
-  if (!is.matrix(z))
-    stop("z is not a matrix")
-  if (ncol(z) != theta$d)
-    stop("Number of colums of z does not equal theta$d")
-  
+  if (!is.theta(theta)) {
+    stop("theta is formatted incorrectly. is.theta(theta) is not TRUE.")
+  }
+  if (!is.matrix(z)) {
+    stop("z is not a matrix. is.matrix(z) is not TRUE.")
+  }
+  if (ncol(z) != theta$d) {
+    stop("Number of columns of z does not equal theta$d.")
+  }
   pgmm_marginal(z = z, mus = theta$mu, sigmas = theta$sigma, pie = theta$pie)
 }
 
@@ -16,11 +18,11 @@ pgmm.marginal <- function (z, theta) {
 #   # z is a n by d matrix. (1st col is evaluated in 1st marginal and so on.)
 #   tz <- t(z)
 #   Margs <- function(k)
-#     t(theta$pie[[k]]*pnorm(tz, mean = theta$mu[[k]], 
+#     t(theta$pie[[k]]*pnorm(tz, mean = theta$mu[[k]],
 #                            sd = sqrt(diag(theta$sigma[[k]]))))
 #   components <- lapply(1:theta$m, Margs)
 #   res <- Reduce('+', components)
-# 
+#
 #   return(res)
 # }
 
@@ -29,7 +31,7 @@ pgmm.marginal <- function (z, theta) {
 #     z <- cbind(z)
 #   # x is a n by d matrix. (1st col is evaluated in 1st marginal and so on.)
 #   TempFuncMarginal <- function (k,j) {
-#     theta$pie[k]*pnorm(cbind(z)[,j], mean = theta$mu[[k]][j],  
+#     theta$pie[k]*pnorm(cbind(z)[,j], mean = theta$mu[[k]][j],
 #                        sd = sqrt(diag(theta$sigma[[k]])[j]))
 #   }
 #   TempAggregate <- function (j) {
